@@ -66,3 +66,15 @@ Scale for dichotomous output from 0 to 1
 dichotomous_scale_0_1 = [0.00, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90, 1.00]
 dictionary_dichotomous_stand = norm_dict(dichotomous_scale_0_1)
 
+#takes a variable name in string form and determines which dictionary to use
+def find_the_dictionary(string, dictionary_0, dictionary_log1, dictionary_log2):
+    if string.startswith('ln1'):
+        output = dictionary_log1
+        name = 'log_transformed_dictionary'
+    elif string.startswith('ln2'):
+        output = dictionary_log2
+        name = 'log2_transformed_dictionary'
+    else:
+        output = dictionary_0
+        name = 'non_transformed_dictionary'
+    return {name:output}
\ No newline at end of file
