@@ -2,7 +2,7 @@
 Small functions enabling ease of writing recursive mapping code
 And simplifying the lookup and conversion of month and country ids
 """
-
+import pandas as pd
 from ingester3.ViewsMonth import ViewsMonth
 from ingester3.Country import Country
 import pycountry
@@ -110,6 +110,16 @@ def give_me_top10_country_id(df, month_value, var_name):
     output = list(temp2.groupby('country_id').groups.keys())
     return output
 
+def give_me_topX_country_id_cumulative(df, time_index, number_wanted, variable, start, end):
+    df = df.reset_index()
+    df = df.set_index(['country_id', str(time_index)])
+    time_wanted = list(range(start, end+1))
+    temp = df[df.index.get_level_values(str(time_index)).isin(time_wanted)]
+    temp2 = pd.DataFrame(temp.groupby('country_id').agg({str(variable):'sum'}))
+    temp3 = temp2.nlargest(number_wanted, str(variable))
+    output = list(temp3.groupby('country_id').groups.keys())
+    return output
+
 def give_me_top10_names(df, month_value, var_name):
     """the dataframe must contain month_id and country_id columns with those names"""
     df = df.reset_index()
@@ -123,6 +133,21 @@ def give_me_top10_names(df, month_value, var_name):
     output = list_1
     return output
 
+def give_me_topX_country_names_cumulative(df, time_index, number_wanted, variable, start, end):
+    df = df.reset_index()
+    df = df.set_index(['country_id', str(time_index)])
+    time_wanted = list(range(start, end+1))
+    temp = df[df.index.get_level_values(str(time_index)).isin(time_wanted)]
+    temp2 = pd.DataFrame(temp.groupby('country_id').agg({str(variable):'sum'}))
+    temp3 = temp2.nlargest(number_wanted, str(variable))
+
+    list_1 = list()
+    for i in list(temp3.groupby('country_id').groups.keys()):
+        list_1.append(Country(i).name)
+    output = list_1
+
+    return output
+
 def make_a_folder(folderpath):
     if not os.path.exists(folderpath):
         os.mkdir(folderpath)
